from setuptools import setup

long_description="""Speech Recognition wave2words 

This package is a test sample and contains two functions and acts as a single program: 
a pronunciation/rhythm/stress words-phrases game (English). The package could be customized for
a speech-to-text system by accepting input from a microphone or an audio file or both. The 
package could be structured for any language of choice.  

In this package, we will test our wave2word speech recognition using AI, for English. However,
in the future releases, other languages will be added to make a language-independent speech
recognition.   

Concept

We may guess a word from unknown spoken languages just by listening to the sound of the Speech. 
To us, in an interaction between a human and a machine, the machine should recognise sounds before
making sense of any words (built from the combination of sounds) meaning. In other words, 
without pre-determining the language a speech recognition should pick up sounds and form words. 

Our speech processing system focuses on the process of understanding the acoustic features of 
sounds, then building words that are spoken by human beings. The speech signals are captured with 
the help of a microphone and then they are to be understood by the system.

The difficulty of speech recognition technology can be broadly characterised along some 
dimensions such as 1)size of a specific language vocabulary pool, 2)speaker dependency-sounds of
a particular word vary from a person to another, 3) the importance of channel quality; human speech
contains high bandwidth with full frequency range, while a telephone speech consists of low 
bandwidth with limited frequency range, 4)speaking mode that is whether the speech is in isolated
word mode, or connected word mode, or in a continuous speech mode. A continuous speech is 
harder to recognize, 5)speaking style; a loud-read speech, spontaneous and conversational, 6) type 
of the noise − signal to noise ratio may be in various ranges, depending on the acoustic environment
that observes less versus more background noise, 7) microphone quality and the distance between mouth 
and microphone. 

Recording and Sampling

During recording with a microphone, the signals are stored in a digitised form. But to work upon it, 
the machine needs them in the discrete numeric form. Hence, our algorithm should sample the signals
at a particular frequency and convert the signal into the discrete numerical form. Choosing the high
frequency for sampling implies that when humans listen to the signal, they feel it as a continuous
audio signal.

Transforming to Frequency Domain

Characterising an audio signal involves converting the time domain signal into the frequency domain, 
and understanding its frequency components that is an essential step because it gives a lot of information
about the signal. You can use a mathematical tool like Fourier Transform to perform this transformation. 
This transformation is the most critical step in building a speech recogniser because after converting the 
speech signal into the frequency domain, we must convert it into the usable form of the feature vector.
 We can use different feature extraction techniques like MFCC, PLP, PLP-RASTA etc. for this purpose.

Myvoicerecognition is unique in its aim to provide a complete quantitative and analytical way to study the acoustic
features of a speech. Moreover, those features could be analysed further by employing Python's functionality
to provide more fascinating insights into speech patterns. 

This library is for Linguists, scientists, developers, speech and language therapy clinics and researchers.   
Please note that Myvoicerecognition Analysis is currently in the initial state though in active development. While 
the amount of functionality that is now present is not huge; more will be added over the next few months.

=============
Installation
=============
Myvoicerecognition can be installed like any other Python library, using (a recent version of) the Python package 
manager pip, on Linux, macOS, and Windows:

------------- pip install Myvoicerecognition ------------------------------
or, to update your installed version to the latest release:
-------------    pip install -u Myvoicerecognition ---------------------------------

NOTE: 

You need to get the following packages installed: 
-----the Microsoft Visual C++ Redistributable for Visual Studio 2017 ------x86 or x64-----see your system
-----PyAudio---PyAudio>= 0.2.11---pip install PyAudio (win),
----------------------------------$ sudo apt-get install python-pyaudio python3-pyaudio (Debian-based Linux
----------------------------------$ brew install portaudio ----$ pip install pyaudio (MaC)
-----PyAudio-0.2.11-cp37-cp37m-win32.whl or win64.whl -----if your system throws an error for PyAudio 

you may get the third file from 
---------- https://github.com/Shahabks/Myvoicerecognition------
save it in a directory and in cmd (command line).../directory/ pip install PyAudio-0.2.11-cp37-cp37m-winxx.whl.

The package uses the default system microphone. If your system has no default microphone, or you want to use 
a microphone other than the default, you will need to specify which one to use by supplying a device index. 

To check how the Myvoicerecognition functions behave, please check 
---------------- EXAMPLES.docx on --------
------------- https://github.com/Shahabks/Myvoicerecognition-----

Myvoicerecognition was developed by MYOLUTIONS Lab in Japan. It is part of New Generation of Voice
Recognition and Acoustic & Language modeling Project in MYSOLUTIONS Lab. That is planned to enrich 
the functionality of Myvoicerecognition by adding more advanced functions."""
	
	
setup(name='Myvoicerecognition',
      version='1',
      description='a speech recognition system structured based on an acoustic and a language model' ,
	  long_description=long_description,
	  url='https://github.com/Shahabks/Myvoicerecognition',
      author='Shahab Sabahi',
      author_email='sabahi.s@mysol-gc.jp',
      license='MIT',
      classifiers=[
		'Intended Audience :: Developers',
		'Intended Audience :: Science/Research',
		'Programming Language :: Python',
		'Programming Language :: Python :: 3.7',
		],
	  keywords='praat speech signal processing phonetics',
	  install_requires=[
		'numpy>=1.15.2',
		'SpeechRecognition>=3.8.1',
		'pandas>=0.23.4',
		'scipy>=1.1.0',
		],
	  packages=['Myvoicerecognition'],
      zip_safe=False)
	  



import random
import time
import speech_recognition as sr

def recognize_speech_from_mic(recognizer, microphone):
    """Transcribe speech from recorded from `microphone`.

    Returns a dictionary with three keys:
    "success": a boolean indicating whether or not the API request was
               successful
    "error":   `None` if no error occured, otherwise a string containing
               an error message if the API could not be reached or
               speech was unrecognizable
    "transcription": `None` if speech could not be transcribed,
               otherwise a string containing the transcribed text
    """
    # check that recognizer and microphone arguments are appropriate type
    if not isinstance(recognizer, sr.Recognizer):
        raise TypeError("`recognizer` must be `Recognizer` instance")

    if not isinstance(microphone, sr.Microphone):
        raise TypeError("`microphone` must be `Microphone` instance")

    # adjust the recognizer sensitivity to ambient noise and record audio
    # from the microphone
    with microphone as source:
        recognizer.adjust_for_ambient_noise(source)
        audio = recognizer.listen(source)

    # set up the response object
    response = {
        "success": True,
        "error": None,
        "transcription": None
    }

    # try recognizing the speech in the recording
    # if a RequestError or UnknownValueError exception is caught,
    #     update the response object accordingly
    try:
        response["transcription"] = recognizer.recognize_google(audio)
    except sr.RequestError:
        # API was unreachable or unresponsive
        response["success"] = False
        response["error"] = "API unavailable"
    except sr.UnknownValueError:
        # speech was unintelligible
        response["error"] = "Unable to recognize speech"

    return response


if __name__ == "__main__":
    # set the list of words, maxnumber of guesses, and prompt limit
    me=input("You are going to play a small game that picks a random word,    EITHER a) from a predefined list by the computer and gives the user three attempts to guess the word      OR b) from your direct inputs; a choice of phrases or words. ------------Type ME for entering your inputs - Type YOU for the machine inputs.:       ")
    if me=="me":
        a1=input("your word-1")
        a2=input("your word-2")
        a3=input("your word-3")
        a4=input("your word-4")
        a5=input("your word-5")
        a6=input("your word-6")
        WORD = [a1, a2, a3, a4, a5, a6]
    else:
        WORD = ["apple", "banana", "right", "orange", "light", "lemon","watermelon","berry","rice","cherry","very","computer","who is that","should I leave now"]
    WORDS=WORD
    NUM_GUESSES = 3
    PROMPT_LIMIT = 5    

    # create recognizer and mic instances
    recognizer = sr.Recognizer()
    microphone = sr.Microphone()

    # get a random word from the list
    word = random.choice(WORDS)

    # format the instructions string
    instructions = (
        "I'm thinking of one of these words:\n"
        "{words}\n"
        "You have {n} tries to guess which one.\n"
    ).format(words=', '.join(WORDS), n=NUM_GUESSES)

    # show instructions and wait 3 seconds before starting the game
    print(instructions)
    time.sleep(3)

    for i in range(NUM_GUESSES):
        # get the guess from the user
        # if a transcription is returned, break out of the loop and
        #     continue
        # if no transcription returned and API request failed, break
        #     loop and continue
        # if API request succeeded but no transcription was returned,
        #     re-prompt the user to say their guess again. Do this up
        #     to PROMPT_LIMIT times
        for j in range(PROMPT_LIMIT):
            print('Guess {}. Speak!'.format(i+1))
            guess = recognize_speech_from_mic(recognizer, microphone)
            if guess["transcription"]:
                break
            if not guess["success"]:
                break
            print("I didn't catch that. What did you say?\n")

        # if there was an error, stop the game
        if guess["error"]:
            print("ERROR: {}".format(guess["error"]))
            break

        # show the user the transcription
        print("You said: {}".format(guess["transcription"]))

        # determine if guess is correct and if any attempts remain
        guess_is_correct = guess["transcription"].lower() == word.lower()
        user_has_more_attempts = i < NUM_GUESSES - 1

        # determine if the user has won the game
        # if not, repeat the loop if user has more attempts
        # if no attempts left, the user loses the game
        if guess_is_correct:
            print("Correct! You win!".format(word))
            break
        elif user_has_more_attempts:
            print("Incorrect. Try again.\n")
        else:
            print("Sorry, you lose!\nI was thinking of '{}'.".format(word))
            break

